@@ -20,12 +20,12 @@
 #include <string.h>
 #include "rt_nonfinite.h"
 #include "rtwtypes.h"
-//#include "omp.h"
 #include "MAVEfast_types.h"
 
 /* Function Declarations */
-extern void rdivide(const emxArray_real_T *x, const emxArray_real_T *y,
-                    emxArray_real_T *z);
+extern void b_rdivide(const emxArray_real_T *x, const emxArray_real_T *y,
+                      emxArray_real_T *z);
+extern void rdivide(const emxArray_real_T *y, emxArray_real_T *z);
 
 #endif
 
